﻿var template_file_1 = "genuino101_curieble.ino_1.template";
var template_file_2 = "genuino101_curieble.ino_2.template";

function LineBreak()
{
    return "\r\n";
}


function GetInfo(infoObject) {
    infoObject.Name = "Genuino 101 CurieBLE";
    infoObject.Description = "Generates source code for Genuino/Arduino 101 using the CurieBLE library";
    infoObject.Author = "Martin Woolley (Twitter: @bluetooth_mdw)";
    infoObject.Version = "1.0.0";
    infoObject.IsClient = false;
    return infoObject;
}


function RunPlugin(profiledata)
{

    log("Plugin -- Begin");

    var template1 = FileManager.ReadFile(template_file_1);
    var template2 = FileManager.ReadFile(template_file_2);

    var part1 = ProcessTemplate(template1, profiledata);
    
    var gap_declarations = "\r\n// GAP properties\r\n";
    if (profiledata.GAPProperties != null)
	{
        if (profiledata.GAPProperties.DeviceName != null && profiledata.GAPProperties.DeviceName != '') {
            if (profiledata.GAPProperties.UseShortName == true) {
                gap_declarations = gap_declarations + 'char device_name[] = "'+profiledata.GAPProperties.DeviceName.substring(0,profiledata.GAPProperties.ShortNameBytes)+'";\r\n';
            } else {
                gap_declarations = gap_declarations + 'char device_name[] = "'+profiledata.GAPProperties.DeviceName+'";\r\n';
            }
        }
    }

    var props_declarations = "\r\n// Characteristic Properties\r\n";  
    
    for (var x = 0; x < profiledata.Services.length; x++) {
        var service = profiledata.Services[x];
        var svc_id = removeUnwanted(service.Name);
        for (var y = 0; y < service.Characteristics.length; y++) {
            var characteristic = service.Characteristics[y];
   		    var char_props_id = svc_id + '_' + removeUnwanted(characteristic.Name) + '_props';
            props_declarations = props_declarations + 'unsigned char '+char_props_id+' = ';
			if (characteristic.Properties[0].Indicate == 'Mandatory' || characteristic.Properties[0].Indicate == 'Optional') {
			    props_declarations = props_declarations + 'BLEIndicate | ';
			}
			if (characteristic.Properties[0].Notify == 'Mandatory' || characteristic.Properties[0].Indicate == 'Optional') {
			    props_declarations = props_declarations + 'BLENotify | ';
			}
			if (characteristic.Properties[0].Read == 'Mandatory' || characteristic.Properties[0].Indicate == 'Optional') {
			    props_declarations = props_declarations + 'BLERead | ';
			}
			if (characteristic.Properties[0].Write == 'Mandatory' || characteristic.Properties[0].Indicate == 'Optional') {
			    props_declarations = props_declarations + 'BLEWrite | ';
			}
			if (characteristic.Properties[0].WriteWithoutResponse == 'Mandatory' || characteristic.Properties[0].Indicate == 'Optional') {
			    props_declarations = props_declarations + 'BLEWriteWithoutResponse | ';
			}
	        props_declarations = props_declarations + '0;\r\n';
		}
	}

    var part2 = ProcessTemplate(template2, profiledata);
    
    var output = part1 + gap_declarations + props_declarations + part2;

    FileManager.CreateFile(removeUnwanted(profiledata.ProfileName) + ".ino", output);

}

function removeUnwanted(input) {
    var output = input.replace(new RegExp(" ", 'g'),"");
    output = output.replace(new RegExp("-", 'g'),"");
    return output;
}